==> plugins-11.3.0.tgz: plugins/volkovlabs-table-panel/README.md <==
# Business Table for Grafana

![Table](https://github.com/VolkovLabs/business-table/raw/main/src/img/dashboard.png)

![Grafana](https://img.shields.io/badge/Grafana-11.3-orange)
![CI](https://github.com/volkovlabs/business-table/workflows/CI/badge.svg)
![E2E](https://github.com/volkovlabs/business-table/workflows/E2E/badge.svg)
[![codecov](https://codecov.io/gh/VolkovLabs/business-table/branch/main/graph/badge.svg)](https://codecov.io/gh/VolkovLabs/business-table)
[![CodeQL](https://github.com/VolkovLabs/business-table/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/VolkovLabs/business-table/actions/workflows/codeql-analysis.yml)

## Introduction

The Business Table panel is a Grafana plugin that allows to simplify data visualization in table format.

[![Business Table panel for Grafana 1.3.0 | Overview and tutorial for beginners](https://raw.githubusercontent.com/volkovlabs/business-table/main/img/overview.png)](https://youtu.be/kOjt9Bl3VQo)

## Requirements

- Business Table panel 1.X requires **Grafana 10.3** or **Grafana 11**.

## Getting Started

You can install the Business Table panel plugin from the [Grafana Plugins catalog](https://grafana.com/grafana/plugins/volkovlabs-table-panel/) or use the Grafana command line tool.

For the latter, please use the following command:

```bash
grafana-cli plugins install volkovlabs-table-panel
```

## Highlights

- Tree View with expandable and collapsible elements.
- Supporting tabs for multiple data frame views.
- Filtering data using dashboard variables.
- Server-side pagination.
- Grafana's Thresholds are incorporated.

## Business Suite for Grafana

The Business Suite is a collection of open source plugins created and actively maintained by Volkov Labs.

The collection aims to solve the most frequent business tasks by providing an intuitive interface with detailed written documentation, examples, and video tutorials.

[![Business Suite for Grafana](https://raw.githubusercontent.com/VolkovLabs/.github/main/business.png)](https://volkovlabs.io/plugins/)

### Enterprise Support

With the [Business Suite Enterprise](https://volkovlabs.io/pricing/), you're not just getting a product, you're getting a complete support system. You'll have a designated support team ready to tackle any issues.

You can contact us via Zendesk, receive priority in feature requests and bug fixes, meet with us for in-person consultation, and get access to the Business Intelligence. It's a package that's designed to make your life easier.

## Always happy to hear from you

- Ask a question, request a new feature, and file a bug with [GitHub issues](https://github.com/volkovlabs/business-table/issues).
- Subscribe to our [YouTube Channel](https://youtube.com/@volkovlabs) and leave your comments.
- Become a [Business Suite sponsor](https://github.com/sponsors/VolkovLabs).

## License

Apache License Version 2.0, see [LICENSE](https://github.com/volkovlabs/business-table/blob/main/LICENSE).

==> plugins-11.4.0.tgz: plugins/volkovlabs-table-panel/README.md <==
# Business Table for Grafana

![Table](https://github.com/VolkovLabs/business-table/raw/main/src/img/dashboard.png)

![Grafana](https://img.shields.io/badge/Grafana-11.3-orange)
![CI](https://github.com/volkovlabs/business-table/workflows/CI/badge.svg)
![E2E](https://github.com/volkovlabs/business-table/workflows/E2E/badge.svg)
[![codecov](https://codecov.io/gh/VolkovLabs/business-table/branch/main/graph/badge.svg)](https://codecov.io/gh/VolkovLabs/business-table)
[![CodeQL](https://github.com/VolkovLabs/business-table/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/VolkovLabs/business-table/actions/workflows/codeql-analysis.yml)

## Introduction

The Business Table panel is a Grafana plugin that allows to simplify data visualization in table format.

[![Business Table panel for Grafana 1.3.0 | Overview and tutorial for beginners](https://raw.githubusercontent.com/volkovlabs/business-table/main/img/overview.png)](https://youtu.be/kOjt9Bl3VQo)

## Requirements

- Business Table panel 1.X requires **Grafana 10.3** or **Grafana 11**.

## Getting Started

You can install the Business Table panel plugin from the [Grafana Plugins catalog](https://grafana.com/grafana/plugins/volkovlabs-table-panel/) or use the Grafana command line tool.

For the latter, please use the following command:

```bash
grafana cli plugins install volkovlabs-table-panel
```

[![Install Business Suite plugins in Cloud, OSS, Enterprise | Open source community plugins](https://raw.githubusercontent.com/volkovlabs/.github/main/started.png)](https://youtu.be/1qYzHfPXJF8)

## Highlights

- Tree View with expandable and collapsible elements.
- Supporting tabs for multiple data frame views.
- Filtering data using dashboard variables.
- Server-side pagination.
- Grafana's Thresholds are incorporated.

## Business Suite for Grafana

The Business Suite is a collection of open source plugins created and actively maintained by Volkov Labs.

The collection aims to solve the most frequent business tasks by providing an intuitive interface with detailed written documentation, examples, and video tutorials.

[![Business Suite for Grafana](https://raw.githubusercontent.com/VolkovLabs/.github/main/business.png)](https://volkovlabs.io/plugins/)

### Enterprise Support

With the [Business Suite Enterprise](https://volkovlabs.io/pricing/), you're not just getting a product, you're getting a complete support system. You'll have a designated support team ready to tackle any issues.

You can contact us via Zendesk, receive priority in feature requests and bug fixes, meet with us for in-person consultation, and get access to the Business Intelligence. It's a package that's designed to make your life easier.

## Always happy to hear from you

- Ask a question, request a new feature, and file a bug with [GitHub issues](https://github.com/volkovlabs/business-table/issues).
- Subscribe to our [YouTube Channel](https://youtube.com/@volkovlabs) and leave your comments.
- Become a [Business Suite sponsor](https://github.com/sponsors/VolkovLabs).

## License

Apache License Version 2.0, see [LICENSE](https://github.com/volkovlabs/business-table/blob/main/LICENSE).
